import * as react from 'react';
import { HTMLMotionProps } from 'framer-motion';
import { WithTransitionConfig } from './transition-utils.js';

interface CollapseTransitionOptions {
    /**
     * If `true`, the opacity of the content will be animated
     * @default true
     */
    animateOpacity?: boolean;
    /**
     * The height you want the content in its collapsed state.
     * @default 0
     */
    startingHeight?: number;
    /**
     * The height you want the content in its expanded state.
     * @default "auto"
     */
    endingHeight?: number | string;
    /**
     * The y-axis offset you want the content in its collapsed state.
     * @default 10
     */
    startingY?: number;
    /**
     * The y-axis offset you want the content in its expanded state.
     * @default 0
     */
    endingY?: number;
}
type ICollapseTransition = CollapseTransitionProps;
interface CollapseTransitionProps extends WithTransitionConfig<HTMLMotionProps<"div">>, CollapseTransitionOptions {
}
declare const CollapseTransition: react.ForwardRefExoticComponent<CollapseTransitionProps & react.RefAttributes<HTMLDivElement>>;

export { CollapseTransition, CollapseTransitionOptions, CollapseTransitionProps, ICollapseTransition };
